| plot_zscore_posterior | R Documentation |
For a single statement, draws the posterior median z-score per factor with nested 50 percent (thick) and 95 percent (thin) credible-interval whiskers, stacked vertically. The x-axis is symmetric around zero so the zero reference is centred.
plot_zscore_posterior(fit, statement, ...)
fit |
A |
statement |
Integer index or statement name. |
... |
Additional arguments forwarded to |
The input, invisibly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.