Skip to contents

Generic for posterior credible intervals, defined here so the package needs no Stan-ecosystem dependency. Compatible with the generic of the same name in rstantools.

Usage

posterior_interval(object, ...)

Arguments

object

A fitted model object.

...

Passed to methods.

Value

See the method documentation.