Skip to contents

Generic for summarizing the priors a model was fit with, defined here so the package needs no Stan-ecosystem dependency. Compatible with the generic of the same name in rstantools.

Usage

prior_summary(object, ...)

Arguments

object

A fitted model object.

...

Passed to methods.

Value

See the method documentation.