Posterior-mean factor z-scores ranked onto the study's forced
distribution. The result is a tidy data frame with one row per
statement and per-factor integer grid scores. For the continuous
z-scores with credible intervals, use compute_zscores().
Posterior-mean factor z-scores ranked onto the study's forced
distribution. The result is a tidy data frame with one row per
statement and per-factor integer grid scores. For the continuous
z-scores with credible intervals, use compute_zscores().