| posterior_interval.bayesqm_fit | R Documentation |
Posterior credible intervals for any subset of parameters in a
bayesqm_fit. Method for rstantools::posterior_interval().
## S3 method for class 'bayesqm_fit'
posterior_interval(object, prob = 0.95, pars = NULL, regex_pars = NULL, ...)
object |
A |
prob |
Coverage probability (default 0.95). |
pars |
Optional character vector of exact parameter names. |
regex_pars |
Optional regex; matching parameter names are included
in addition to those named in |
... |
Unused. |
A matrix with one row per parameter and two columns for the lower and upper interval bounds (as percent strings).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.